@@ -13,7 +13,7 @@ from . import __version__
 
 @click.group()
 @click.version_option(version=__version__)
-def cli():
+def cli() -> None:
     """Access OpenNeuro datasets.
     """
     pass
